Class: Cloudinary::SearchFolders
- Defined in:
- lib/cloudinary/search_folders.rb
Overview
The Cloudinary API folders search method allows you fine control on filtering and retrieving information on all the folders in your cloud with the help of query expressions in a Lucene-like query language.
Constant Summary collapse
- ENDPOINT =
'folders'